@@ -1,6 +1,6 @@
 import pytest
 from random import randint, seed
-from kryptools import dlog
+from kryptools import dlog, primorial
 
 seed(0)
 
@@ -12,7 +12,8 @@ def test_dlogt():
     for data in (
         [557639, 278819, 2],
         [24570203447, 12285101723, 2],
-            [28031135240181527, 14015567620090763, 2]):
+        [28031135240181527, 14015567620090763, 2],
+        [primorial(379)+1, primorial(379)//3, 383]):
         p, m, a = data  # m is the order of a in Z_p
         x = randint(2, m - 1)
         b = pow(a, x, p)
