@@ -75,13 +75,29 @@ def test_is_prime():
         assert is_prime(n) == prime_test[n]
 
 
+# https://oeis.org/A000043
+OEIS_A000043 = [2, 3, 5, 7, 13, 17, 19, 31, 61, 89, 107, 127, 521, 607, 1279, 2203, 2281,
+                 3217, 4253, 4423, 9689, 9941, 11213, 19937, 21701, 23209, 44497, 86243,
+                 110503, 132049, 216091, 756839, 859433, 1257787, 1398269, 2976221,
+                 3021377, 6972593, 13466917, 20996011, 24036583, 25964951, 30402457,
+                 32582657, 37156667, 42643801, 43112609, 57885161]
+
+
+def test_mersenne_prime():
+    for p in range(1000):
+        if not prime_test[p]:
+            continue
+        if p > OEIS_A000043[-1]:
+            break
+        assert is_prime(2**p - 1) == (p in OEIS_A000043)
+
+
 # https://oeis.org/A005385
 OEIS_A005385 = [5, 7, 11, 23, 47, 59, 83, 107, 167, 179, 227, 263, 347, 359, 383, 467,
                 479, 503, 563, 587, 719, 839, 863, 887, 983, 1019, 1187, 1283, 1307, 1319, 1367, 1439,
                 1487, 1523, 1619, 1823, 1907, 2027, 2039, 2063, 2099, 2207, 2447, 2459, 2579, 2819,
                 2879, 2903, 2963]
 
-
 def test_is_safeprime():
     for n in range(OEIS_A005385[-1]+1):
         assert is_safeprime(n) == (n in OEIS_A005385)
